==> vscat-1.0.0.tgz: package/tests/highlighting/sources/json/npm-package/results/output.monokai-dimmed.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test monokai-dimmed theme 1`] = `
Object {
  "lines": Array [
    "[48;2;30;30;30m [38;2;133;133;133m 1 │ [39m[38;2;197;200;198m{[39m                                                                         [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 2 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"name\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"test-package\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 3 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"description\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"Some[39m[38;2;80;80;55m·[39m[38;2;154;168;58museful[39m[38;2;80;80;55m·[39m[38;2;154;168;58mpackage[39m[38;2;80;80;55m·[39m[38;2;154;168;58mto[39m[38;2;80;80;55m·[39m[38;2;154;168;58mdo[39m[38;2;80;80;55m·[39m[38;2;154;168;58msome[39m[38;2;80;80;55m·[39m[38;2;154;168;58museful[39m[38;2;80;80;55m·[39m[38;2;154;168;58mstuff[39m[38;2;80;80;55m·[39m[38;2;154;168;58mwith[39m[38;2;80;80;55m·[39m[38;2;154;168;58madvanc[39m[38;2;154;168;58m…[39m[49m",
    "[48;2;30;30;30m [38;2;133;133;133m 4 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"version\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"1.0.0\\"[39m[38;2;197;200;198m,[39m                                                     [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 5 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"private\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;64;128;128mtrue[39m[38;2;197;200;198m,[39m                                                        [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 6 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"license\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"MIT\\"[39m[38;2;197;200;198m,[39m                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 7 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"dependencies\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;197;200;198m{[39m                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 8 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-1\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"1.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 9 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-2\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"2.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m10 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-3\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"3.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m11 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-4\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"4.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m12 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-5\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"5.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m13 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-6\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;30;30;30m [38;2;133;133;133m14 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;197;200;198m}[39m                                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m15 │ [39m[38;2;197;200;198m}[39m                                                                         [49m",
    "[48;2;30;30;30m [38;2;133;133;133m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #C5C8C6 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #C5C8C6 │   
 1 │  2, 8 │ #C7444A │ \\"name\\"
 1 │  8,10 │ #C5C8C6 │ : 
 1 │ 10,24 │ #9AA83A │ \\"test-package\\"
 1 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #C5C8C6 │   
 2 │  2,15 │ #C7444A │ \\"description\\"
 2 │ 15,17 │ #C5C8C6 │ : 
 2 │ 17,90 │ #9AA83A │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #C5C8C6 │   
 3 │  2,11 │ #C7444A │ \\"version\\"
 3 │ 11,13 │ #C5C8C6 │ : 
 3 │ 13,20 │ #9AA83A │ \\"1.0.0\\"
 3 │ 20,21 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #C5C8C6 │   
 4 │  2,11 │ #C7444A │ \\"private\\"
 4 │ 11,13 │ #C5C8C6 │ : 
 4 │ 13,17 │ #408080 │ true
 4 │ 17,18 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #C5C8C6 │   
 5 │  2,11 │ #C7444A │ \\"license\\"
 5 │ 11,13 │ #C5C8C6 │ : 
 5 │ 13,18 │ #9AA83A │ \\"MIT\\"
 5 │ 18,19 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #C5C8C6 │   
 6 │  2,16 │ #C7444A │ \\"dependencies\\"
 6 │ 16,19 │ #C5C8C6 │ : {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #C5C8C6 │     
 7 │  4,15 │ #C7444A │ \\"package-1\\"
 7 │ 15,17 │ #C5C8C6 │ : 
 7 │ 17,24 │ #9AA83A │ \\"1.0.0\\"
 7 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #C5C8C6 │     
 8 │  4,15 │ #C7444A │ \\"package-2\\"
 8 │ 15,17 │ #C5C8C6 │ : 
 8 │ 17,24 │ #9AA83A │ \\"2.0.0\\"
 8 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #C5C8C6 │     
 9 │  4,15 │ #C7444A │ \\"package-3\\"
 9 │ 15,17 │ #C5C8C6 │ : 
 9 │ 17,24 │ #9AA83A │ \\"3.0.0\\"
 9 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #C5C8C6 │     
10 │  4,15 │ #C7444A │ \\"package-4\\"
10 │ 15,17 │ #C5C8C6 │ : 
10 │ 17,24 │ #9AA83A │ \\"4.0.0\\"
10 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #C5C8C6 │     
11 │  4,15 │ #C7444A │ \\"package-5\\"
11 │ 15,17 │ #C5C8C6 │ : 
11 │ 17,24 │ #9AA83A │ \\"5.0.0\\"
11 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #C5C8C6 │     
12 │  4,15 │ #C7444A │ \\"package-6\\"
12 │ 15,17 │ #C5C8C6 │ : 
12 │ 17,24 │ #9AA83A │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 3 │ #C5C8C6 │   }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #C5C8C6 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/sources/json/npm-package/results/output.monokai-dimmed.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test monokai-dimmed theme 1`] = `
Object {
  "lines": Array [
    "[48;2;30;30;30m [38;2;133;133;133m 1 │ [39m[38;2;197;200;198m{[39m                                                                         [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 2 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"name\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"test-package\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 3 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"description\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"Some[39m[38;2;80;80;55m·[39m[38;2;154;168;58museful[39m[38;2;80;80;55m·[39m[38;2;154;168;58mpackage[39m[38;2;80;80;55m·[39m[38;2;154;168;58mto[39m[38;2;80;80;55m·[39m[38;2;154;168;58mdo[39m[38;2;80;80;55m·[39m[38;2;154;168;58msome[39m[38;2;80;80;55m·[39m[38;2;154;168;58museful[39m[38;2;80;80;55m·[39m[38;2;154;168;58mstuff[39m[38;2;80;80;55m·[39m[38;2;154;168;58mwith[39m[38;2;80;80;55m·[39m[38;2;154;168;58madvanc…[39m[49m",
    "[48;2;30;30;30m [38;2;133;133;133m 4 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"version\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"1.0.0\\"[39m[38;2;197;200;198m,[39m                                                     [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 5 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"private\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;64;128;128mtrue[39m[38;2;197;200;198m,[39m                                                        [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 6 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"license\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"MIT\\"[39m[38;2;197;200;198m,[39m                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 7 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"dependencies\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;197;200;198m{[39m                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 8 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-1\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"1.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 9 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-2\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"2.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m10 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-3\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"3.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m11 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-4\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"4.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m12 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-5\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"5.0.0\\"[39m[38;2;197;200;198m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m13 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;199;68;74m\\"package-6\\"[39m[38;2;197;200;198m:[39m[38;2;80;80;55m·[39m[38;2;154;168;58m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;30;30;30m [38;2;133;133;133m14 │ [39m[38;2;80;80;55m·[39m[38;2;80;80;55m·[39m[38;2;197;200;198m}[39m                                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m15 │ [39m[38;2;197;200;198m}[39m                                                                         [49m",
    "[48;2;30;30;30m [38;2;133;133;133m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #C5C8C6 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #C5C8C6 │   
 1 │  2, 8 │ #C7444A │ \\"name\\"
 1 │  8,10 │ #C5C8C6 │ : 
 1 │ 10,24 │ #9AA83A │ \\"test-package\\"
 1 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #C5C8C6 │   
 2 │  2,15 │ #C7444A │ \\"description\\"
 2 │ 15,17 │ #C5C8C6 │ : 
 2 │ 17,90 │ #9AA83A │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #C5C8C6 │   
 3 │  2,11 │ #C7444A │ \\"version\\"
 3 │ 11,13 │ #C5C8C6 │ : 
 3 │ 13,20 │ #9AA83A │ \\"1.0.0\\"
 3 │ 20,21 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #C5C8C6 │   
 4 │  2,11 │ #C7444A │ \\"private\\"
 4 │ 11,13 │ #C5C8C6 │ : 
 4 │ 13,17 │ #408080 │ true
 4 │ 17,18 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #C5C8C6 │   
 5 │  2,11 │ #C7444A │ \\"license\\"
 5 │ 11,13 │ #C5C8C6 │ : 
 5 │ 13,18 │ #9AA83A │ \\"MIT\\"
 5 │ 18,19 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #C5C8C6 │   
 6 │  2,16 │ #C7444A │ \\"dependencies\\"
 6 │ 16,19 │ #C5C8C6 │ : {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #C5C8C6 │     
 7 │  4,15 │ #C7444A │ \\"package-1\\"
 7 │ 15,17 │ #C5C8C6 │ : 
 7 │ 17,24 │ #9AA83A │ \\"1.0.0\\"
 7 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #C5C8C6 │     
 8 │  4,15 │ #C7444A │ \\"package-2\\"
 8 │ 15,17 │ #C5C8C6 │ : 
 8 │ 17,24 │ #9AA83A │ \\"2.0.0\\"
 8 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #C5C8C6 │     
 9 │  4,15 │ #C7444A │ \\"package-3\\"
 9 │ 15,17 │ #C5C8C6 │ : 
 9 │ 17,24 │ #9AA83A │ \\"3.0.0\\"
 9 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #C5C8C6 │     
10 │  4,15 │ #C7444A │ \\"package-4\\"
10 │ 15,17 │ #C5C8C6 │ : 
10 │ 17,24 │ #9AA83A │ \\"4.0.0\\"
10 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #C5C8C6 │     
11 │  4,15 │ #C7444A │ \\"package-5\\"
11 │ 15,17 │ #C5C8C6 │ : 
11 │ 17,24 │ #9AA83A │ \\"5.0.0\\"
11 │ 24,25 │ #C5C8C6 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #C5C8C6 │     
12 │  4,15 │ #C7444A │ \\"package-6\\"
12 │ 15,17 │ #C5C8C6 │ : 
12 │ 17,24 │ #9AA83A │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 3 │ #C5C8C6 │   }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #C5C8C6 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;
